/*
 * Copyright 2019-2021 The OpenSSL Project Authors. All Rights Reserved.
 *
 * Licensed under the Apache License 2.0 (the "License").  You may not use
 * this file except in compliance with the License.  You can obtain a copy
 * in the file LICENSE in the source distribution or at
 * https://www.openssl.org/source/license.html
 */

#ifndef OPENSSL_OPENSSLCONF_H
#define OPENSSL_OPENSSLCONF_H
#pragma once

#include <openssl/configuration.h>
#include <openssl/macros.h>

#endif /* OPENSSL_OPENSSLCONF_H */
